/*
   Copyright 2013 Harri Smatt

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */

package fi.harism.lucidchat;

import android.app.Dialog;
import android.content.Context;
import android.view.View;
import android.view.Window;
import android.widget.CheckBox;
import android.widget.EditText;

/**
 * Connect dialog handler class.
 */
public class DialogConnect extends Dialog {

	private DialogObserver mObserver;

	public DialogConnect(Context context, DialogObserver observer) {
		super(context);
		mObserver = observer;
		requestWindowFeature(Window.FEATURE_NO_TITLE);
		setContentView(R.layout.dialog_connect);
		findViewById(R.id.button_cancel).setOnClickListener(
				new View.OnClickListener() {
					@Override
					public void onClick(View v) {
						mObserver.onCancel(DialogConnect.this);
					}
				});
		findViewById(R.id.button_connect).setOnClickListener(
				new View.OnClickListener() {
					@Override
					public void onClick(View v) {
						mObserver.onConnect(DialogConnect.this);
					}
				});
	}

	public boolean getAutojoin() {
		return ((CheckBox) findViewById(R.id.checkbox_autojoin)).isChecked();
	}

	public String getName() {
		return ((EditText) findViewById(R.id.edittext_name)).getText()
				.toString();
	}

	public String getRealName() {
		return ((EditText) findViewById(R.id.edittext_realname)).getText()
				.toString();
	}

	@Override
	public void onBackPressed() {
		mObserver.onCancel(this);
	}

	public void setAutojoin(boolean autojoin) {
		((CheckBox) findViewById(R.id.checkbox_autojoin)).setChecked(autojoin);
	}

	public void setName(String name) {
		((EditText) findViewById(R.id.edittext_name)).setText(name);
	}

	public void setRealName(String realName) {
		((EditText) findViewById(R.id.edittext_realname)).setText(realName);
	}

	public interface DialogObserver {
		public void onCancel(DialogConnect dialog);

		public void onConnect(DialogConnect dialog);
	}
}
