/*
   Copyright 2013 Harri Smatt

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */

package fi.harism.lucidchat;

import android.content.Context;
import android.content.SharedPreferences;

/**
 * Application preferences handler class.
 */
public class PreferencesHandler {

	// Static key values for preferences.
	private static final String KEY_AUTOJOIN = "key.autojoin";
	private static final String KEY_NAME = "key.name";
	private static final String KEY_REALNAME = "key.realname";
	private static final String PREFS_FILE = "lucidchat.conf";

	private boolean mAutojoin;
	private Context mContext;
	private String mName, mRealName;

	public PreferencesHandler(Context context) {
		mContext = context;

		SharedPreferences prefs = mContext.getSharedPreferences(PREFS_FILE,
				Context.MODE_PRIVATE);
		mName = prefs.getString(KEY_NAME, "");
		mRealName = prefs.getString(KEY_REALNAME, "");
		mAutojoin = prefs.getBoolean(KEY_AUTOJOIN, true);
	}

	public boolean getAutojoin() {
		return mAutojoin;
	}

	public String getName() {
		return mName;
	}

	public String getRealName() {
		return mRealName;
	}

	public void save() {
		SharedPreferences prefs = mContext.getSharedPreferences(PREFS_FILE,
				Context.MODE_PRIVATE);
		SharedPreferences.Editor editor = prefs.edit();
		editor.putString(KEY_NAME, mName);
		editor.putString(KEY_REALNAME, mRealName);
		editor.putBoolean(KEY_AUTOJOIN, mAutojoin);
		editor.commit();
	}

	public void setAutojoin(boolean autojoin) {
		mAutojoin = autojoin;
	}

	public void setName(String name) {
		mName = name;
	}

	public void setRealName(String realName) {
		mRealName = realName;
	}

}
