/*
   Copyright 2013 Harri Smatt

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */

package fi.harism.lucidchat;

import java.util.Timer;
import java.util.TimerTask;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.view.Window;
import android.view.animation.AlphaAnimation;
import android.view.animation.AnimationSet;
import android.view.animation.TranslateAnimation;

/**
 * Splash screen Activity.
 */
public class SplashActivity extends Activity {

	private Timer mTimer;

	@Override
	public void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		requestWindowFeature(Window.FEATURE_NO_TITLE);
		setContentView(R.layout.layout_splash);

		// Set timer for showing main Activity.
		mTimer = new Timer();
		mTimer.schedule(new TimerTask() {
			@Override
			public void run() {
				runOnUiThread(new Runnable() {
					@Override
					public void run() {
						Intent intent = new Intent(SplashActivity.this,
								MainActivity.class);
						startActivity(intent);
						finish();
						overridePendingTransition(android.R.anim.slide_in_left,
								android.R.anim.slide_out_right);
					}
				});
			}
		}, 3000);

		// Animate in splash texts.
		View splashTitle = findViewById(R.id.view_splash_title);
		View splashDescription = findViewById(R.id.view_splash_description);

		AlphaAnimation alphaIn = new AlphaAnimation(0, 1);
		TranslateAnimation transLeft = new TranslateAnimation(-100, 0, 0, 0);
		TranslateAnimation transRight = new TranslateAnimation(100, 0, 0, 0);
		AnimationSet animLeft = new AnimationSet(true);
		animLeft.addAnimation(alphaIn);
		animLeft.addAnimation(transLeft);
		animLeft.setDuration(1000);
		AnimationSet animRight = new AnimationSet(true);
		animRight.addAnimation(alphaIn);
		animRight.addAnimation(transRight);
		animRight.setDuration(1000);

		splashTitle.setAnimation(animLeft);
		splashDescription.setAnimation(animRight);

		animLeft.startNow();
		animRight.startNow();
	}

	@Override
	public void onDestroy() {
		super.onDestroy();
		mTimer.cancel();
	}

}
